@@ -15,7 +15,7 @@ use Scalar::Util qw/blessed/;
 # GLOBALS
 #======================================================================
 
-our $VERSION  = '1.49_03';
+our $VERSION  = '1.49_04';
 $VERSION      = eval $VERSION; # numify for warning-free dev releases
 
 
@@ -1881,8 +1881,11 @@ This would create:
 
 Note that you must pass the bind values in the same format as they are returned
 by C</where>. That means that if you set L</bindtype> to C<columns>, you must
-provide the bind values in the C<< [ column_name => value ] >> format, so eg.
-the above example will look like:
+provide the bind values in the C<< [ column_meta => value ] >> format, where
+C<column_meta> is an opaque scalar value; most commonly the column name, but
+you can use any scalar scalar value (including references and blessed
+references), L<SQL::Abstract> will simply pass it through intact. So eg. the
+above example will look like:
 
     my %where = (
        date_column => \[q/= date '2008-09-30' - ?::integer/, [ dummy => 10 ]/]
